@@ -17,9 +17,9 @@
 nbrOfWorkers.batchjobs <- function(evaluator) {
   ## Infer from 'workers' argument
   expr <- formals(evaluator)$workers
-  workers <- eval(expr)
+  workers <- eval(expr, enclos = baseenv())
   if (!is.null(workers)) {
-    stopifnot(length(workers) >= 1)
+    stop_if_not(length(workers) >= 1)
     if (is.numeric(workers)) return(prod(workers))
     if (is.character(workers)) return(length(workers))
     stop("Invalid data type of 'workers': ", mode(workers))
@@ -32,7 +32,7 @@ nbrOfWorkers.batchjobs <- function(evaluator) {
 #' @export
 nbrOfWorkers.batchjobs_multicore <- function(evaluator) {
   expr <- formals(evaluator)$workers
-  workers <- eval(expr)
-  stopifnot(length(workers) == 1, !is.na(workers), workers >= 1, is.finite(workers))
+  workers <- eval(expr, enclos = baseenv())
+  stop_if_not(length(workers) == 1, !is.na(workers), workers >= 1, is.finite(workers))
   workers
 }
