@@ -3,6 +3,38 @@ isNA <- function(x) {
   is.na(x)
 }
 
+
+stop_if_not <- function(...) {
+  res <- list(...)
+  for (ii in 1L:length(res)) {
+    res_ii <- .subset2(res, ii)
+    if (length(res_ii) != 1L || is.na(res_ii) || !res_ii) {
+        mc <- match.call()
+        call <- deparse(mc[[ii + 1]], width.cutoff = 60L)
+        if (length(call) > 1L) call <- paste(call[1L], "....")
+        stop(sprintf("%s is not TRUE", sQuote(call)),
+             call. = FALSE, domain = NA)
+    }
+  }
+  
+  NULL
+}
+stop_if_not <- function(...) {
+  res <- list(...)
+  for (ii in 1L:length(res)) {
+    res_ii <- .subset2(res, ii)
+    if (length(res_ii) != 1L || is.na(res_ii) || !res_ii) {
+        mc <- match.call()
+        call <- deparse(mc[[ii + 1]], width.cutoff = 60L)
+        if (length(call) > 1L) call <- paste(call[1L], "....")
+        stop(sprintf("%s is not TRUE", sQuote(call)),
+             call. = FALSE, domain = NA)
+    }
+  }
+  
+  NULL
+}
+
 attachedPackages <- function() {
   pkgs <- search()
   pkgs <- grep("^package:", pkgs, value=TRUE)
@@ -69,7 +101,7 @@ captureOutput <- function(expr, envir=parent.frame(), ...) {
     on.exit(close(file))
     capture.output(expr, file=file)
     rawToChar(rawConnectionValue(file))
-  }, envir=envir, enclos=envir)
+  }, envir=envir, enclos = baseenv())
   unlist(strsplit(res, split="\n", fixed=TRUE), use.names=FALSE)
 }
 
@@ -107,9 +139,9 @@ importBatchJobs <- function(name, default=NULL) {
 ## as small as possible, which is why we use local().  Without,
 ## the environment would be that of the package itself and all of
 ## the package would be exported.
-geval <- local(function(expr, substitute=FALSE, envir=.GlobalEnv, ...) {
+geval <- local(function(expr, substitute=FALSE, envir=.GlobalEnv, enclos = baseenv(), ...) {
   if (substitute) expr <- substitute(expr)
-  eval(expr, envir=envir)
+  eval(expr, envir=envir, enclos = enclos)
 })
 
 
@@ -121,3 +153,17 @@ isOS <- function(name) {
     grepl(paste0("^", name), R.version$os)
   }
 } ## isOS()
+
+
+## Suppress:
+##   "Warning in result_fetch(res@ptr, n = n) :
+##    Don't need to call dbFetch() for statements, only for queries"
+## from DBI::dbFetch() when called by BatchJobs::makeRegistry().
+## This is because BatchJobs has not been updated according to the
+## updates in DBI.
+suppressDBIWarnings <- function(expr) {
+  ops <- options(warn = -1L)
+  on.exit(options(ops))
+  withCallingHandlers(expr,
+                      warning = function(w) invokeRestart("muffleWarning"))
+}
